/**

  Spago4Q - The Business Intelligence Free Platform

  Copyright (C) 2009 Engineering Ingegneria Informatica S.p.A.

  Spago4Q is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  Spago4Q is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this library; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

 **/
package it.eng.spago4q.extractors.tablehandlers.postgresql;

import it.eng.spago.dbaccess.sql.DataConnection;
import it.eng.spago.error.EMFUserError;
import it.eng.spago4q.extractors.tablehandlers.AbstractTableHandler;
import it.eng.spago4q.extractors.tablehandlers.SqlCodeGeneratorInterface;

import java.util.List;

public class PostgreSqlTableHandler extends AbstractTableHandler {

	private SqlCodeGeneratorInterface codeGenerator;

	public PostgreSqlTableHandler() {
		codeGenerator = new PostgreSqlCodeGenerator();
	}

	@Override
	public void createFactTable(final DataConnection dataConnection,
			final String tableName, final List interfaceFieldList) throws EMFUserError {
		// sequence
		String sequenceQuery = PostgreSqlCodeGenerator
				.generateCreateSequenceQuery(tableName);
		// table
		String createQuery = getSqlCodeGenerator().generateCreateTableQuery(
				tableName, interfaceFieldList);
		queryExecutor(dataConnection, sequenceQuery + createQuery);
	}

	@Override
	public void dropFactTable(final DataConnection connection, final String tableName)
			throws EMFUserError {
		// sequence
		String dropSequenceQuery = PostgreSqlCodeGenerator
				.generateDropSequenceQuery(tableName);
		// table
		String dropQuery = getSqlCodeGenerator()
				.generateDropTableQuery(tableName);
		queryExecutor(connection, dropQuery + dropSequenceQuery);
	}

	@Override
	public SqlCodeGeneratorInterface getSqlCodeGenerator() {
		return codeGenerator;
	}

}
